@@ -1251,7 +1251,7 @@ g_daemon_vfs_local_file_set_attributes (GVfs       *vfs,
             {
               g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
                            _("Error setting file metadata: %s"),
-                           _("can't open metadata tree"));
+                           _("can’t open metadata tree"));
               res = FALSE;
               error = NULL; /* Don't set further errors */
             }
@@ -1262,7 +1262,7 @@ g_daemon_vfs_local_file_set_attributes (GVfs       *vfs,
 		{
 		  g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
 			       _("Error setting file metadata: %s"),
-			       _("can't get metadata proxy"));
+			       _("can’t get metadata proxy"));
 		  res = FALSE;
 		  error = NULL; /* Don't set further errors */
 		}
@@ -1356,11 +1356,16 @@ g_daemon_vfs_local_file_removed (GVfs       *vfs,
       if (proxy)
         {
           metatreefile = meta_tree_get_filename (tree);
-          gvfs_metadata_call_remove_sync (proxy,
-                                          metatreefile,
-                                          tree_path,
-                                          NULL,
-                                          NULL);
+          /* we don't care about the result, let's queue the call and don't block */
+          gvfs_metadata_call_remove (proxy,
+                                     metatreefile,
+                                     tree_path,
+                                     NULL,
+                                     NULL, /* callback */
+                                     NULL);
+          /* flush the call with the expense of sending all queued messages on the connection */
+          g_dbus_connection_flush_sync (g_dbus_proxy_get_connection (G_DBUS_PROXY (proxy)),
+                                        NULL, NULL);
         }
       
       meta_tree_unref (tree);
@@ -1398,12 +1403,17 @@ g_daemon_vfs_local_file_moved (GVfs       *vfs,
       if (proxy)
         {
           metatreefile = meta_tree_get_filename (tree1);
-          gvfs_metadata_call_move_sync (proxy,
-                                        metatreefile,
-                                        tree_path1,
-                                        tree_path2,
-                                        NULL,
-                                        NULL);
+          /* we don't care about the result, let's queue the call and don't block */
+          gvfs_metadata_call_move (proxy,
+                                   metatreefile,
+                                   tree_path1,
+                                   tree_path2,
+                                   NULL,
+                                   NULL, /* callback */
+                                   NULL);
+          /* flush the call with the expense of sending all queued messages on the connection */
+          g_dbus_connection_flush_sync (g_dbus_proxy_get_connection (G_DBUS_PROXY (proxy)),
+                                        NULL, NULL);
         }
     }
 
