@@ -1965,7 +1965,7 @@ do_mount (GVfsBackend  *backend,
     soup_message_headers_clear (msg_stat->response_headers);
     soup_message_body_truncate (msg_stat->response_body);
 
-  } while (strcmp (mount_base->path, "/") != 0);
+  } while (g_strcmp0 (last_good_path, "/") != 0);
 
   /* we either encountered an error or we have
      reached the end of paths we are allowed to
@@ -2864,12 +2864,12 @@ do_move (GVfsBackend *backend,
                     g_vfs_job_failed_literal (G_VFS_JOB(job),
                                               G_IO_ERROR,
                                               G_IO_ERROR_WOULD_MERGE,
-                                              _("Can't move directory over directory"));
+                                              _("Can’t move directory over directory"));
                   else
                     g_vfs_job_failed_literal (G_VFS_JOB(job),
                                               G_IO_ERROR,
                                               G_IO_ERROR_IS_DIRECTORY,
-                                              _("Can't move over directory"));
+                                              _("Can’t move over directory"));
                   goto error;
                 }
               else if (source_ft == G_FILE_TYPE_DIRECTORY)
@@ -2987,7 +2987,7 @@ do_copy (GVfsBackend *backend,
                 g_vfs_job_failed_literal (G_VFS_JOB(job),
                                           G_IO_ERROR,
                                           G_IO_ERROR_WOULD_MERGE,
-                                          _("Can't copy directory over directory"));
+                                          _("Can’t copy directory over directory"));
               else
                 g_vfs_job_failed_literal (G_VFS_JOB(job),
                                           G_IO_ERROR,
@@ -3016,7 +3016,7 @@ do_copy (GVfsBackend *backend,
       g_vfs_job_failed_literal (G_VFS_JOB (job),
                                 G_IO_ERROR,
                                 G_IO_ERROR_WOULD_RECURSE,
-                                _("Can't recursively copy directory"));
+                                _("Can’t recursively copy directory"));
       goto error;
     }
 
