@@ -344,7 +344,7 @@ open_for_read_fstat_cb (int err,
           g_vfs_job_failed_literal (job,
                                     G_IO_ERROR,
                                     G_IO_ERROR_IS_DIRECTORY,
-                                    _("Can't open directory"));
+                                    _("Can’t open directory"));
           return;
         }
     }
@@ -1603,6 +1603,8 @@ try_query_fs_info (GVfsBackend *backend,
 
   g_file_info_set_attribute_string (info,
                                     G_FILE_ATTRIBUTE_FILESYSTEM_TYPE, "nfs");
+  g_file_info_set_attribute_boolean (info,
+                                     G_FILE_ATTRIBUTE_FILESYSTEM_REMOTE, TRUE);
 
   if (g_file_attribute_matcher_matches (matcher,
                                         G_FILE_ATTRIBUTE_FILESYSTEM_SIZE) ||
@@ -2467,7 +2469,7 @@ move_stat_dest_cb (int err,
                 {
                   g_vfs_job_failed_literal (job,
                                             G_IO_ERROR, G_IO_ERROR_WOULD_MERGE,
-                                            _("Can't move directory over directory"));
+                                            _("Can’t move directory over directory"));
                 }
               else
                 {
