@@ -313,44 +313,6 @@ auth_callback (SMBCCTX *context,
 
 #define SUB_DELIM_CHARS  "!$&'()*+,;="
 
-static gboolean
-is_valid (char c, const char *reserved_chars_allowed)
-{
-  if (g_ascii_isalnum (c) ||
-      c == '-' ||
-      c == '.' ||
-      c == '_' ||
-      c == '~')
-    return TRUE;
-
-  if (reserved_chars_allowed &&
-      strchr (reserved_chars_allowed, c) != NULL)
-    return TRUE;
-  
-  return FALSE;
-}
-
-static void
-g_string_append_encoded (GString *string,
-			 const char *encoded,
-			 const char *reserved_chars_allowed)
-{
-  char c;
-  static const gchar hex[16] = "0123456789ABCDEF";
-  
-  while ((c = *encoded++) != 0)
-    {
-      if (is_valid (c, reserved_chars_allowed))
-	g_string_append_c (string, c);
-      else
-	{
-	  g_string_append_c (string, '%');
-	  g_string_append_c (string, hex[((guchar)c) >> 4]);
-	  g_string_append_c (string, hex[((guchar)c) & 0xf]);
-	}
-    }
-}
-
 static GString *
 create_smb_uri_string (const char *server,
 		       int port,
@@ -360,16 +322,30 @@ create_smb_uri_string (const char *server,
   GString *uri;
 
   uri = g_string_new ("smb://");
-  g_string_append_encoded (uri, server, NULL);
+  if (server == NULL)
+    return uri;
+
+  /* IPv6 server includes brackets in GMountSpec, smbclient doesn't */
+  if (server[0] == '[')
+    {
+      g_string_append_uri_escaped (uri, server + 1, NULL, FALSE);
+      g_string_truncate (uri, uri->len - 3);
+    }
+  else
+    g_string_append_uri_escaped (uri, server, NULL, FALSE);
+
   if (port != -1)
     g_string_append_printf (uri, ":%d", port);
   g_string_append_c (uri, '/');
-  g_string_append_encoded (uri, share, NULL);
+
+  if (share != NULL)
+    g_string_append_uri_escaped (uri, share, NULL, FALSE);
+
   if (path != NULL)
     {
       if (*path != '/')
 	g_string_append_c (uri, '/');
-      g_string_append_encoded (uri, path, SUB_DELIM_CHARS ":@/");
+      g_string_append_uri_escaped (uri, path, SUB_DELIM_CHARS ":@/", FALSE);
     }
 
   while (uri->len > 0 &&
@@ -379,7 +355,7 @@ create_smb_uri_string (const char *server,
   return uri;
 }
 
-static char *
+char *
 create_smb_uri (const char *server,
 		int port,
 		const char *share,
@@ -704,14 +680,6 @@ do_read (GVfsBackend *backend,
   ssize_t res;
   smbc_read_fn smbc_read;
 
-  /* libsmbclient limits blocksize to (64*1024)-2 for Windows servers,
-   * let's do the same here to achieve reasonable performance. (#588391)
-   *
-   * TODO: port to pull mechanism (#592468)
-   */
-  if (bytes_requested > 65534)
-    bytes_requested = 65534;
-
   smbc_read = smbc_getFunctionRead (op_backend->smb_context);
   res = smbc_read (op_backend->smb_context, (SMBCFILE *)handle, buffer, bytes_requested);
 
@@ -1826,9 +1794,7 @@ do_enumerate (GVfsBackend *backend,
 	    {
 	      int stat_res;
 	      g_string_truncate (uri, uri_start_len);
-	      g_string_append_encoded (uri,
-				       dirp->name,
-				       SUB_DELIM_CHARS ":@/");
+              g_string_append_uri_escaped (uri, dirp->name, SUB_DELIM_CHARS ":@/", FALSE);
 
 	      if (matcher == NULL ||
 		  g_file_attribute_matcher_matches_only (matcher, G_FILE_ATTRIBUTE_STANDARD_NAME))
